package models

import (
	"github.com/beego/beego/v2/client/orm"
)

type CygxArticle struct {
	Id               int    `orm:"column(id);pk"`
	ArticleId        int    `description:"文章id"`
	Title            string `description:"标题"`
	TitleEn          string `description:"英文标题 "`
	UpdateFrequency  string `description:"更新周期"`
	CreateDate       string `description:"创建时间"`
	PublishDate      string `description:"发布时间"`
	Body             string `description:"内容"`
	BodyText         string `description:"内容"`
	Abstract         string `description:"摘要"`
	CategoryName     string `description:"一级分类"`
	SubCategoryName  string `description:"二级分类"`
	PublishStatus    int    `description:"发布状态"`
	CategoryId       int    `description:"分类id"`
	CategoryIdTwo    int    `description:"分类id用作修改匹配类型使用"`
	ExpertBackground string `description:"专家背景"`
	ExpertNumber     string `description:"专家编号"`
	InterviewDate    string `description:"访谈日期"`
	Department       string `description:"作者"`
	ArticleIdMd5     string `description:"ID，md5值"`
	IsClass          int    `description:"是否归类，1是，0否"`
	IsSummary        int    `description:"是否是纪要库，1是，0否"`
	IsReport         int    `description:"是否属于报告，1是，0否"`
	ReportType       int    `description:"报告类型，1行业报告，2产业报告,0无"`
	FileLink         string `description:"下载预览链接"`
	MatchTypeName    string `description:"匹配类型"`
	Periods          string `description:"期数"`
	ReportLink       string `description:"报告链接"`
	ArticleType      string `description:"文章类型 文章类型，lyjh:路演精华 "`
	HavePublish      int    `description:"是否发布过，1是 ，0 否"`
	Source           int    `description:"来源 0策略平台同步，1小程序后台添加"`
	SellerAndMobile  string `description:"销售和手机号"`
	VideoUrl         string `description:"音频文件URL"`
	VideoName        string `description:"音频文件名称"`
	VideoPlaySeconds string `description:"音频播放时长"`
	Stock            string `description:"个股标签"`
	FieldName        string `description:"产业标签"`
	Annotation       string `description:"核心观点"`
	TypeName         string `description:"策略平台报告类型"`
	ModifyTimeByCl   string `description:"策略平台报告更新时间"`
	CeLueFieldId     int    `description:"策略平台领域ID"`
}

type ArticleDetail struct {
	ArticleId            int             `description:"报告id"`
	ArticleIdMd5         string          `description:"报告MD5id"`
	IsReport             int             `description:"是否属于报告，1是，0否"`
	Title                string          `description:"标题"`
	CategoryName         string          `description:"一级分类"`
	CategoryId           int             `description:"分类ID"`
	CreateDate           string          `description:"创建时间"`
	PublishDate          string          `description:"发布时间"`
	Body                 string          `description:"内容"`
	Abstract             string          `description:"摘要"`
	Annotation           string          `description:"核心观点"`
	IsInterviewApply     bool            `description:"是否申请访谈:true，已申请，false:未申请"`
	InterviewApplyStatus string          `description:"当前访谈申请状态：'待邀请','待访谈','已完成','已取消'"`
	IsFollow             bool            `description:"是否关注，1是，0否"`
	FollowNum            int             `description:"关注数量"`
	IsCollect            bool            `description:"是否收藏:true，已收藏，false:未收藏"`
	CollectionNum        int             `description:"收藏数量"`
	DepartmentId         int             `description:"作者ID"`
	DepartmentImgUrl     string          `description:"作者头像"`
	NickName             string          `description:"作者昵称"`
	HttpUrl              string          `description:"文章链接跳转地址"`
	IsNeedJump           bool            `description:"是否需要跳转链接地址"`
	Seller               SellerResp      `description:"作者昵称"`
	DepartmentDetail     *DepartmentResp `description:"作者昵称"`
	Disclaimers          string          `description:"免责声明"`
	IsSpecialArticle     bool            `description:"是否属于专项调研报告"`
	SubCategoryName      string          `description:"二级分类"`
	ArticleTypeId        int             `description:"文章类型ID"`
}

type SellerResp struct {
	SellerMobile string `description:"销售手机号"`
	SellerName   string `description:"销售名称"`
}

type ArticleDetailResp struct {
	IsResearch       bool   `description:"是否属于研选"`
	Mobile           string `description:"用户手机号"`
	PopupMsg         string `description:"权限弹窗信息"`
	SellerMobile     string `description:"销售电话"`
	SellerName       string `description:"销售姓名"`
	Detail           *ArticleDetail
	IsSpecialArticle bool `description:"是否属于专项调研报告"`
	HasPermission    int  `description:"1:有该行业权限,正常展示，2：无该行业权限，不存在权益客户下，3:无该品类权限,已提交过申请，4：无该行业权限,未提交过申请，5：潜在客户，未提交过申请，6：潜在客户,已提交过申请"`
}

func GetArticleDetailById(articleId int) (item *ArticleDetail, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_article WHERE article_id = ?  AND publish_status = 1  `
	err = o.Raw(sql, articleId).QueryRow(&item)
	return
}

func GetArticlePermission(companyId int) (item *ChartPermission, err error) {
	o := orm.NewOrm()
	sql := `SELECT
			a.chart_permission_name as  permission_name
			FROM
			cygx_report_mapping AS a
			WHERE
			a.category_id = ?`
	err = o.Raw(sql, companyId).QueryRow(&item)
	return
}

type ArticleFollowDetail struct {
	DNum   int `description:"作者被关注的数量"`
	MdNum  int `description:"本人是否关注这个作者"`
	AcNum  int `description:"文章被收藏的数量"`
	MacNum int `description:"本人是否收藏这个文章"`
}

// 获取文章被关注被收藏的详情
func GetArticleFollowDetail(articleId, uid int) (item *ArticleFollowDetail, err error) {
	//d_num 作者被关注的数量 、 md_num 本人是否关注这个作者 、ac_num 文章被收藏的数量 、 mac_num 本人是否收藏这个文章
	o := orm.NewOrm()
	sql := ` SELECT
	( SELECT count( 1 ) FROM cygx_article_department_follow AS af INNER JOIN wx_user as u ON  u.user_id = af.user_id  WHERE af.department_id = art.department_id AND af.type = 1 ) AS d_num,
	( SELECT count( 1 ) FROM cygx_article_department_follow AS af WHERE af.department_id = art.department_id AND af.type = 1 AND af.user_id = ? ) AS md_num,
	( SELECT count( 1 ) FROM cygx_article_collect AS ac INNER JOIN wx_user as u ON  u.user_id = ac.user_id  WHERE ac.article_id = art.article_id  ) AS ac_num,
	( SELECT count( 1 ) FROM cygx_article_collect AS ac WHERE ac.article_id = art.article_id  AND ac.user_id = ? ) AS mac_num
FROM
	cygx_article AS art
	LEFT JOIN cygx_article_department_follow AS af ON af.department_id = art.department_id
	LEFT JOIN cygx_article_collect AS ac ON ac.article_id = art.article_id 
WHERE
	art.article_id = ?
	GROUP BY art.article_id `
	err = o.Raw(sql, uid, uid, articleId).QueryRow(&item)
	return
}

func GetArticleCountById(articleId int) (count int, err error) {
	o := orm.NewOrm()
	sql := `SELECT COUNT(1) AS count FROM cygx_article WHERE article_id = ? `
	err = o.Raw(sql, articleId).QueryRow(&count)
	return
}

// 用户收藏榜start
type ArticleCollectionResp struct {
	ArticleId       int                         `description:"文章id"`
	Title           string                      `description:"标题"`
	PublishDate     string                      `description:"发布时间"`
	DepartmentId    int                         `description:"作者Id"`
	NickName        string                      `description:"作者昵称"`
	IsCollect       bool                        `description:"本人是否收藏"`
	Pv              int                         `description:"PV"`
	CollectNum      int                         `description:"收藏人数"`
	Source          int                         `description:"来源 1:弘则资源包（报告）、2：研选主题（报告）"`
	List            []*IndustrialManagementResp `description:"产业列表"`
	Body            string                      `description:"内容"`
	Abstract        string                      `description:"摘要"`
	Annotation      string                      `description:"核心观点"`
	CategoryName    string                      `description:"一级分类"`
	SubCategoryName string                      `description:"二级分类"`
	IsResearch      bool                        `description:"是否属于研选"`
	ImgUrlPc        string                      `description:"图片链接"`
	CategoryId      string                      `description:"文章分类"`
	HttpUrl         string                      `description:"文章链接跳转地址"`
	IsNeedJump      bool                        `description:"是否需要跳转链接地址"`
	MyCollectNum    int                         `description:"本人是否收藏数量"`
	ArticleTypeId   int                         `description:"文章类型ID"`
}

// 列表
func GetArticleCollectionList(condition string, userId int) (items []*ArticleCollectionResp, err error) {
	o := orm.NewOrm()
	sql := `SELECT
			a.article_id,
			a.title,
			date_format( a.publish_date, '%Y-%m-%d' ) AS publish_date,
			m.industry_name,
			m.industrial_management_id,
			d.nick_name,
			d.department_id,
			( SELECT count( 1 ) FROM cygx_article_history_record_newpv AS h WHERE h.article_id = a.article_id ) AS pv,
			( SELECT count( 1 ) FROM cygx_article_collect AS ac  INNER JOIN wx_user as u ON  u.user_id = ac.user_id  WHERE ac.article_id = a.article_id  ) AS collect_num, 
			( SELECT count( 1 ) FROM cygx_article_collect AS ac  INNER JOIN wx_user as u ON  u.user_id = ac.user_id  WHERE ac.article_id = a.article_id AND DATE_SUB( CURDATE(), INTERVAL 30 DAY ) <= date( ac.create_time )  ) AS collect_num_order, 
			( SELECT count( 1 ) FROM cygx_article_collect AS ac WHERE ac.article_id = a.article_id  AND user_id = ? ) AS my_collect_num
		FROM
			cygx_article AS a
			INNER JOIN cygx_industrial_article_group_management AS mg ON mg.article_id = a.article_id
			INNER JOIN cygx_industrial_management AS m ON m.industrial_management_id = mg.industrial_management_id
			INNER JOIN cygx_article_department AS d ON d.department_id = a.department_id 
		WHERE
			1 = 1  AND a.publish_status = 1  `
	if condition != "" {
		sql += condition
	}
	_, err = o.Raw(sql, userId).QueryRows(&items)
	return
} //end

type ArticleCollectionLIstResp struct {
	List []*ArticleCollectionResp
}

type CygxArticleEs struct {
	Id               int    `orm:"column(id);pk"`
	ArticleId        int    `description:"文章id"`
	Title            string `description:"标题"`
	TitleEn          string `description:"英文标题 "`
	UpdateFrequency  string `description:"更新周期"`
	CreateDate       string `description:"创建时间"`
	PublishDate      string `description:"发布时间"`
	Body             string `description:"内容"`
	BodyText         string `description:"内容"`
	Abstract         string `description:"摘要"`
	CategoryName     string `description:"一级分类"`
	SubCategoryName  string `description:"二级分类"`
	PublishStatus    int    `description:"发布状态"`
	CategoryId       string `description:"分类id"`
	ExpertBackground string `description:"专家背景"`
	ExpertNumber     string `description:"专家编号"`
	InterviewDate    string `description:"访谈日期"`
	Department       string `description:"作者"`
	ArticleIdMd5     string `description:"ID，md5值"`
	IsClass          int    `description:"是否归类，1是，0否"`
	IsSummary        bool   `description:"是否是纪要库，1是，0否"`
	IsReport         bool   `description:"是否属于报告，1是，0否"`
	ReportType       int    `description:"报告类型，1行业报告，2产业报告,0无"`
	FileLink         string `description:"下载预览链接"`
	MatchTypeName    string `description:"匹配类型"`
}

// 获取文章列表
func GetArticleList(condition string, pars []interface{}) (items []*ArticleDetail, err error) {
	o := orm.NewOrm()
	sql := `SELECT	article_id FROM cygx_article  WHERE 1= 1 ` + condition
	_, err = o.Raw(sql, pars).QueryRows(&items)
	return
}

func GetArticleDetailByIdStr(articleIdStr string) (items []*ArticleDetail, err error) {
	o := orm.NewOrm()
	sql := `SELECT 	art.*,d.nick_name FROM
			cygx_article AS art
			LEFT JOIN cygx_article_department AS d ON d.department_id = art.department_id  WHERE article_id IN(` + articleIdStr + `) `
	_, err = o.Raw(sql).QueryRows(&items)
	return
}

// 检查用户是否阅读某一分类最新文章
func GetUserIsReadThisNewCategoryArticleCount(categoryId, uid int) (count int, err error) {
	sqlCount := `SELECT COUNT(1) as count FROM
	cygx_article_history_record 
	WHERE
	article_id = ( SELECT article_id FROM cygx_article WHERE category_id = ? ORDER BY publish_date DESC LIMIT 0, 1 )
	AND user_id = ?`
	o := orm.NewOrm()
	err = o.Raw(sqlCount, categoryId, uid).QueryRow(&count)
	return
}

// 获取最新文章
func GetNewArticleByCategoryId(categoryId int) (item *ArticleDetail, err error) {
	o := orm.NewOrm()
	sql := ` SELECT * FROM cygx_article WHERE  category_id = ? ORDER BY publish_date DESC LIMIT 0, 1`
	err = o.Raw(sql, categoryId).QueryRow(&item)
	return
}

func GetArticleDetailByIdMd5(articleIdMd5 string) (item *ArticleDetail, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_article WHERE article_id_md5 = ? `
	err = o.Raw(sql, articleIdMd5).QueryRow(&item)
	return
}

type SummaryArticleStock struct {
	Id        int    `description:"新ID"`
	ArticleId int    `description:"文章id"`
	Stock     string `description:"个股标签"`
}

type SummaryArticleStockResp struct {
	List []*SummaryArticleStock
}

// 综述报告
func GetArticleStock() (items []*SummaryArticleStock, err error) {
	o := orm.NewOrm()
	sql := `SELECT
			stock,article_id
		FROM
			cygx_article AS art 
		WHERE
			1 = 1 
			AND type_name = '综述报告' `
	_, err = o.Raw(sql).QueryRows(&items)
	return
}

// 列表
func GetCygxCygxArticleList(condition string, pars []interface{}, startSize, pageSize int) (items []*CygxArticle, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_article as art WHERE 1= 1 `
	if condition != "" {
		sql += condition
	}
	sql += ` LIMIT ?,?  `
	_, err = o.Raw(sql, pars, startSize, pageSize).QueryRows(&items)
	return
}

// 获取数量
func GetCygxArticleCount(condition string, pars []interface{}) (count int, err error) {
	sqlCount := ` SELECT COUNT(1) AS count  FROM cygx_article as art WHERE 1= 1  `
	if condition != "" {
		sqlCount += condition
	}
	o := orm.NewOrm()
	err = o.Raw(sqlCount, pars).QueryRow(&count)
	return
}
