package services

import (
	"errors"
	"hongze/hongze_clpt/models"
	"hongze/hongze_clpt/utils"
	"strings"
)

var (
	UserPermissionOperationModeApply      = "Apply"
	UserPermissionOperationModeCall       = "Call"
	UserPermissionPopupMsgApplyActivity   = "您暂无权限参加此活动，若想参加可以申请开通对应的试用权限"
	UserPermissionPopupMsgCallActivity    = "您暂无权限参加此活动，若想参加可以联系对口销售"
	UserPermissionPopupMsgApplyMicroVideo = "您暂无权限查看此视频，若想查看可以申请开通对应的试用权限"
	UserPermissionPopupMsgApplyMicroVoice = "您暂无权限查看此音频，若想查看可以申请开通对应的试用权限"
	UserPermissionPopupMsgCallMicroVoice  = "您暂无权限查看此音频，若想参加可以联系对口销售"
	UserPermissionPopupMsgCallMicroVideo  = "您暂无权限查看此视频，若想查看可以联系对口销售"
)

// GetUserRaiPermissionInfo 获取权限类型及信息
// HasPermission int `description:"1:有该行业权限,正常展示，2：无该行业权限，不存在权益客户下（ficc），3:无该品类权限,已提交过申请，4：无该品类权限,未提交过申请，5：潜在客户，未提交过申请，6：潜在客户,已提交过申请"`
func GetUserRaiPermissionInfo1(userId, companyId int) (authInfo models.UserPermissionAuthInfo, permissionArr []string, err error) {
	// 用户申请记录
	applyCount, e := models.GetApplyRecordCount(userId)
	if e != nil && e.Error() != utils.ErrNoRow() {
		err = errors.New("获取用户申请信息失败, Err: " + e.Error())
		return
	}

	// 潜在用户
	if companyId <= 1 {
		authInfo.HasPermission = 5
		if applyCount > 0 {
			authInfo.HasPermission = 6
		}
		authInfo.OperationMode = UserPermissionOperationModeApply
		authInfo.PopupMsg = UserPermissionPopupMsgApplyActivity
		return
	}

	// 销售信息
	ficcSeller, e := models.GetSellerByCompanyIdCheckFicc(companyId, utils.COMPANY_PRODUCT_FICC_ID)
	if e != nil && e.Error() != utils.ErrNoRow() {
		err = errors.New("获取FICC销售信息失败, Err: " + e.Error())
		return
	}
	raiSeller, e := models.GetSellerByCompanyIdCheckFicc(companyId, utils.COMPANY_PRODUCT_RAI_ID)
	if e != nil && e.Error() != utils.ErrNoRow() {
		err = errors.New("获取权益销售信息失败, Err: " + e.Error())
		return
	}
	if raiSeller != nil {
		authInfo.SellerMobile = raiSeller.Mobile
		authInfo.SellerName = raiSeller.RealName
		authInfo.HasPermission = 4
		if applyCount > 0 {
			authInfo.HasPermission = 3
		}
		authInfo.OperationMode = UserPermissionOperationModeApply
		authInfo.PopupMsg = UserPermissionPopupMsgApplyActivity
		return
	}
	// 仅有FICC权限
	if ficcSeller != nil {
		authInfo.HasPermission = 2
		authInfo.OperationMode = UserPermissionOperationModeApply
		authInfo.PopupMsg = UserPermissionPopupMsgApplyActivity
		return
	}

	// permissions示例: 医药,消费,科技,智造,策略,专家,买方研选
	permissions, e := models.GetCompanyPermissionName(companyId)
	if e != nil {
		err = errors.New("获取客户权限失败, Err: " + e.Error())
		return
	}
	if permissions == "" {
		// 无权益权限

		// 有销售信息
		authInfo.HasPermission = 2
		authInfo.OperationMode = UserPermissionOperationModeCall
		authInfo.PopupMsg = UserPermissionPopupMsgCallActivity
		return

		// 无销售信息, 无申请, 视作潜在用户
		//authInfo.HasPermission = 3
		//authInfo.OperationMode = UserPermissionOperationModeApply
		//return
	}
	// 有基本的权益权限
	authInfo.HasPermission = 1
	permissionArr = strings.Split(permissions, ",")
	return
}

func GetUserRaiPermissionInfo(userId, companyId int) (authInfo models.UserPermissionAuthInfo, permissionArr []string, err error) {
	// 用户申请记录
	applyCount, e := models.GetApplyRecordCount(userId)
	if e != nil && e.Error() != utils.ErrNoRow() {
		err = errors.New("获取用户申请信息失败, Err: " + e.Error())
		return
	}

	// 潜在用户
	if companyId <= 1 {
		authInfo.HasPermission = 5
		if applyCount > 0 {
			authInfo.HasPermission = 6
		}
		authInfo.OperationMode = UserPermissionOperationModeApply
		authInfo.PopupMsg = UserPermissionPopupMsgApplyActivity
		return
	}

	// 销售信息
	ficcSeller, e := models.GetSellerByCompanyIdCheckFicc(companyId, utils.COMPANY_PRODUCT_FICC_ID)
	if e != nil && e.Error() != utils.ErrNoRow() {
		err = errors.New("获取FICC销售信息失败, Err: " + e.Error())
		return
	}
	raiSeller, e := models.GetSellerByCompanyIdCheckFicc(companyId, utils.COMPANY_PRODUCT_RAI_ID)
	if e != nil && e.Error() != utils.ErrNoRow() {
		err = errors.New("获取权益销售信息失败, Err: " + e.Error())
		return
	}
	if raiSeller != nil {
		authInfo.SellerMobile = raiSeller.Mobile
		authInfo.SellerName = raiSeller.RealName
	}
	// 仅有FICC权限
	if ficcSeller != nil && raiSeller == nil {
		authInfo.HasPermission = 2
		authInfo.OperationMode = UserPermissionOperationModeApply
		authInfo.PopupMsg = UserPermissionPopupMsgApplyActivity
		return
	}

	// permissions示例: 医药,消费,科技,智造,策略,专家,买方研选
	permissions, e := models.GetCompanyPermissionName(companyId)
	if e != nil {
		err = errors.New("获取客户权限失败, Err: " + e.Error())
		return
	}
	if permissions == "" {
		// 无权益权限
		if raiSeller != nil {
			// 有销售信息
			authInfo.HasPermission = 2
			authInfo.OperationMode = UserPermissionOperationModeCall
			authInfo.PopupMsg = UserPermissionPopupMsgCallActivity
			return
		}
		// 无销售信息, 无申请, 视作潜在用户
		authInfo.HasPermission = 3
		authInfo.OperationMode = UserPermissionOperationModeApply
		return
	}
	// 有基本的权益权限
	authInfo.HasPermission = 1
	permissionArr = strings.Split(permissions, ",")
	return
}
